# Generated by Django 2.2.9 on 2020-01-01 16:58

from django.db import migrations
import wagtail_links.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_links', '0006_auto_20200101_1646'),
    ]

    operations = [
        migrations.AlterField(
            model_name='link',
            name='name',
            field=wagtail_links.fields.NullSlugField(help_text='Unique name for this link (for use by Django templates).', unique=True, verbose_name='Name'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-05-22 20:15
from __future__ import unicode_literals

from django.db import migrations, models
import wagtail_links.models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_links', '0002_auto_20170522_1552'),
    ]

    operations = [
        migrations.AlterField(
            model_name='link',
            name='django_view_name',
            field=models.CharField(blank=True, help_text='Name of django view for reverse lookup', max_length=255, validators=[wagtail_links.models.validate_django_reverse]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-05-22 15:52
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_links', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='link',
            name='link_relative',
            field=models.CharField(blank=True, max_length=200, validators=[django.core.validators.RegexValidator(message='Not valid relative url', regex='^(?!www\\.|(?:http|ftp)s?://|[A-Za-z]:\\\\|//).*')], verbose_name='Relative link'),
        ),
    ]



from django.core.exceptions import ImproperlyConfigured
from django.db.models.fields import SlugField


class NullSlugField(SlugField):
    """
    SlugField that stores '' as None and returns None as ''

    Useful when using unique=True and forms. Implies null==blank==True.
    """

    def __init__(self, *args, **kwargs):
        if not kwargs.get('null', True) or not kwargs.get('blank', True):
            raise ImproperlyConfigured("NullCharField implies null==blank==True")
        kwargs['null'] = kwargs['blank'] = True
        super().__init__(*args, **kwargs)


    def from_db_value(self, value, *args, **kwargs):
        value = self.to_python(value)
        # If the value was stored as null, return empty string instead
        return value if value is not None else ''


    def get_prep_value(self, value):
        prepped = super().get_prep_value(value)
        # If the value was stored as empty string, return None instead
        return prepped if prepped != "" else None


    def deconstruct(self):
        name, path, args, kwargs = super().deconstruct()
        del kwargs['null']
        del kwargs['blank']
        return name, path, args, kwargs



# Generated by Django 2.1.8 on 2019-04-11 21:02

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import wagtail_links.models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_links', '0003_auto_20170522_2015'),
    ]

    operations = [
        migrations.AddField(
            model_name='link',
            name='name',
            field=models.SlugField(help_text='Unique name for this link (for use by Django templates).', null=True, unique=True, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='link',
            name='django_view_name',
            field=models.CharField(blank=True, help_text='Name of Django view for reverse lookup', max_length=255, validators=[wagtail_links.models.validate_django_reverse]),
        ),
        migrations.AlterField(
            model_name='link',
            name='link_external',
            field=models.URLField(blank=True, help_text='Absolute URL Link', verbose_name='External link'),
        ),
        migrations.AlterField(
            model_name='link',
            name='link_page',
            field=models.ForeignKey(blank=True, help_text='Wagtail Page Link', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailcore.Page'),
        ),
        migrations.AlterField(
            model_name='link',
            name='link_relative',
            field=models.CharField(blank=True, help_text='Relative URL Link', max_length=200, validators=[django.core.validators.RegexValidator(message='Not valid relative url', regex='^(?!www\\.|(?:http|ftp)s?://|[A-Za-z]:\\\\|//).*')], verbose_name='Relative link'),
        ),
    ]



#!/usr/bin/env python
from setuptools import setup, find_packages, Distribution
import codecs
import os.path

# Make sure versiontag exists before going any further
Distribution().fetch_build_eggs('versiontag>=1.2.0')

from versiontag import get_version, cache_git_tag  # NOQA


packages = find_packages('src')

install_requires = [
    'wagtail>=2.0',
]

extras_require = {
    'development': [
        'flake8>=3.3.0',
        'tox>=2.7.0',
        'versiontag>=1.2.0',
    ],
}


def fpath(name):
    return os.path.join(os.path.dirname(__file__), name)


def read(fname):
    return codecs.open(fpath(fname), encoding='utf-8').read()


cache_git_tag()

setup(
    name="wagtail-links",
    description="Wagtail links provides a consistent way to refer to links in a wagtail page.",
    version=get_version(pypi=True),
    long_description=open('README.rst').read(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Wagtail',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Intended Audience :: Developers',
        "License :: OSI Approved :: Apache Software License",
    ],
    keywords="django wagtail",
    author="David Burke",
    author_email="dburke@thelabnyc.com",
    url="https://gitlab.com/thelabnyc/wagtail-links",
    license="Apache License",
    package_dir={'': 'src'},
    packages=packages,
    include_package_data=True,
    install_requires=install_requires,
    extras_require=extras_require,
)



# Generated by Django 2.2.9 on 2020-01-01 16:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_links', '0005_auto_20191203_1908_squashed_0006_auto_20191204_2129'),
    ]

    operations = [
        migrations.AlterField(
            model_name='link',
            name='title',
            field=models.CharField(blank=True, help_text='Description of link for use in ARIA compliance', max_length=200, verbose_name='Title'),
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class WagtailLinksConfig(AppConfig):
    name = 'wagtail_links'
    # Translators: Backend Library Name
    verbose_name = _('Wagtail Links')



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-05-22 15:04
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0033_remove_golive_expiry_help_text'),
    ]

    operations = [
        migrations.CreateModel(
            name='Link',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('link_external', models.URLField(blank=True, verbose_name='External link')),
                ('link_relative', models.URLField(blank=True, verbose_name='External link')),
                ('django_view_name', models.CharField(blank=True, help_text='Name of django view for reverse lookup', max_length=255)),
                ('link_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailcore.Page')),
            ],
        ),
    ]
